@@ -158,6 +158,10 @@ class OvsHost(linux.LinuxDevice):
         self.cmd('ovs-ctl start')
         self.cmd('systemctl start docker')
 
+        cmd = "ls -l /sys/class/net/ | egrep -v 'virtual|total' | awk -F / '{print $NF}'"
+        self.nics = self.cmd(cmd, log_level = 4).split()
+        self.log("host's phicial nics: %s" %(self.nics))
+
         #vlog: 0: no change. 1: emer, 2: err, 3: warn, 4: info, 5: dbg, -1: off
         self["vlog"] = (self["vlog"]) and int(self["vlog"]) or 0
         if (self["vlog"] > 0):
@@ -238,7 +242,11 @@ class OvsHost(linux.LinuxDevice):
         ports = ports if (isinstance(ports, list)) else [ports]
         ports = ports if (not args) else ports.extend(args)
         for p in ports:
-            self.add_port(name, p)
+            if (p.get("type", "normal") == "normal") and (p["name"] in self.nics):
+                #If it's a normal interface, take over it
+                self.takeover_interface(name, p["name"])
+            else:
+                self.add_port(name, p)
 
     def add_port (self, bridge_name, kwargs):
         '''
@@ -261,7 +269,8 @@ class OvsHost(linux.LinuxDevice):
         #If it's a normal interface, flush it to release its original ip address.
         #if (kwargs.get("type", "normal") == "normal"):
         #    #self.cmd("ip addr flush dev %s" %(name))
-        #    self.cmd("sh ovstools.sh takeover %s %s" %(bridge_name, name))
+        #    #self.cmd("sh ovstools.sh takeover %s %s" %(bridge_name, name))
+        #    self.takeover_interface(bridge_name, name)
 
         macaddr = self.ovs_get_interface(name, "mac_in_use").strip('"')
         kwargs["mac"] = macaddr
@@ -558,7 +567,12 @@ class OvsHost(linux.LinuxDevice):
                 # delete all the devices(container/vm/physical) connectting to.
                 external_ids = self.ovs_get_interface(p.strip(), "external_ids")
                 external_ids = external_ids.strip("{} \t\r\n")
-                if ("=" in external_ids):
+
+                #self.log("bridge: %s, port: %s" %(b.strip(), p.strip()))
+                if (p.strip() in self.nics):
+                    # Restore the "phisical" interface
+                    self.no_takeover_interface(b.strip(), p)
+                elif ("=" in external_ids):
                     # Parse external_ids: {container_id=con13, container_iface=eth1}
                     i = {}
                     for a in external_ids.split(",", 1):
@@ -569,7 +583,7 @@ class OvsHost(linux.LinuxDevice):
                         self.cmd('docker rm %s' %(i["container_id"]))
             self.cmd("ovs-vsctl del-br %s" %(b.strip()))
         self.cmd('ovs-vsctl show')
-        self.cmd('ovs-ctl stop')
+        #self.cmd('ovs-ctl stop')
 
     def ovs_get_interface (self, interface, attribute = None):
         '''
